package djmil.cordacheckers.states;

import net.corda.v5.base.annotations.ConstructorForDeserialization;
import net.corda.v5.base.annotations.CordaSerializable;

@CordaSerializable
public class Piece {
    
    @CordaSerializable
    public enum Type {
        MAN,
        KING;
    }

    @CordaSerializable
    public enum Color {
        WHITE,
        BLACK;

        public Color opposite() {
            switch (this) {
                case WHITE:
                    return BLACK;
                case BLACK:
                    return WHITE;
            }
            throw new RuntimeException("Unknown Color");
        }
    }

    private final Color color;
    private final Type type;

    @ConstructorForDeserialization
    public Piece(Color color, Type type) {
        this.color = color;
        this.type = type;
    }

    public Color getColor() {
        return color;
    }

    public Type getType() {
        return type;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        Piece other = (Piece) obj;
        if (color != other.color)
            return false;
        if (type != other.type)
            return false;
        return true;
    }

}
